@@ -1,5 +1,7 @@
 #define PY_SSIZE_T_CLEAN
 #include <Python.h>
+#include <datetime.h>
+#include <inttypes.h>
 #include <string.h>
 #include <stdbool.h>
 #include <limits.h>
@@ -13,7 +15,6 @@
 #include <stdint.h>
 #include <math.h>
 #include <structmember.h>
-#include <datetime.h>
 #include "module.h"
 #include "halffloat.h"
 #include "tags.h"
@@ -348,8 +349,8 @@ _CBORDecoder_get_immutable(CBORDecoderObject *self, void *closure)
 
 // Utility functions /////////////////////////////////////////////////////////
 
-static int
-raise_from(const PyObject *new_exc_type, const char *message) {
+static void
+raise_from(PyObject *new_exc_type, const char *message) {
     // This requires the error indicator to be set
     PyObject *cause;
 #if PY_VERSION_HEX >= 0x030c0000
@@ -694,7 +695,7 @@ decode_bytestring(CBORDecoderObject *self, uint8_t subtype)
         return NULL;
 
     if (length > (uint64_t)PY_SSIZE_T_MAX - (uint64_t)PyBytesObject_SIZE) {
-        sprintf(length_hex, "%llX", length);
+        sprintf(length_hex, "%" PRIX64, length);
         PyErr_Format(
                 _CBOR2_CBORDecodeValueError,
                 "excessive bytestring size 0x%s", length_hex);
@@ -894,7 +895,7 @@ decode_string(CBORDecoderObject *self, uint8_t subtype)
     if (decode_length(self, subtype, &length, &indefinite) == -1)
         return NULL;
     if (length > (uint64_t)PY_SSIZE_T_MAX - (uint64_t)PyBytesObject_SIZE) {
-        sprintf(length_hex, "%llX", length);
+        sprintf(length_hex, "%" PRIX64, length);
         PyErr_Format(
                 _CBOR2_CBORDecodeValueError,
                 "excessive string size 0x%s", length_hex);
@@ -1057,7 +1058,7 @@ decode_array(CBORDecoderObject *self, uint8_t subtype)
     if (indefinite)
         return decode_indefinite_array(self);
     if (length > (uint64_t)PY_SSIZE_T_MAX) {
-        sprintf(length_hex, "%llX", length);
+        sprintf(length_hex, "%" PRIX64, length);
         PyErr_Format(
                 _CBOR2_CBORDecodeValueError,
                 "excessive array size 0x%s", length_hex);
@@ -1338,15 +1339,16 @@ static PyObject *
 CBORDecoder_decode_epoch_date(CBORDecoderObject *self)
 {
     // semantic type 100
-    PyObject *num, *tuple, *ret = NULL;
+    PyObject *num, *ordinal, *ret = NULL;
 
     num = decode(self, DECODE_NORMAL);
     if (num) {
         if (PyNumber_Check(num)) {
-            tuple = PyTuple_Pack(1, PyNumber_Multiply(num, PyLong_FromLong(24 * 60 * 60)));
-            if (tuple) {
-                ret = PyDate_FromTimestamp(tuple);
-                Py_DECREF(tuple);
+            ordinal = PyNumber_Add(num, _CBOR2_date_ordinal_offset);
+            if (ordinal) {
+                ret = PyObject_CallMethodObjArgs(
+                    (PyObject*) PyDateTimeAPI->DateType, _CBOR2_str_fromordinal, ordinal, NULL);
+                Py_DECREF(ordinal);
             }
         } else {
             PyErr_Format(
