@@ -1040,8 +1040,6 @@ CBOREncoder_encode_date(CBOREncoderObject *self, PyObject *value)
     // semantic type 100 or 1004
 
     PyObject *tmp, *ret = NULL;
-    const char *buf;
-    Py_ssize_t length;
     if (self->date_as_datetime) {
         tmp = PyDateTimeAPI->DateTime_FromDateAndTime(
                 PyDateTime_GET_YEAR(value),
@@ -1056,7 +1054,7 @@ CBOREncoder_encode_date(CBOREncoderObject *self, PyObject *value)
         tmp = PyObject_CallMethodObjArgs(
                 value, _CBOR2_str_toordinal, NULL);
         if (tmp && fp_write(self, "\xD8\x64", 2) == 0) {
-            ret = CBOREncoder_encode_int(self, PyNumber_Subtract(tmp, PyLong_FromLong(719163)));
+            ret = CBOREncoder_encode_int(self, PyNumber_Subtract(tmp, _CBOR2_date_ordinal_offset));
         }
     } else {
         tmp = PyObject_CallMethodObjArgs(
@@ -1120,7 +1118,7 @@ decimal_negative(PyObject *value)
 static PyObject *
 encode_decimal_digits(CBOREncoderObject *self, PyObject *value)
 {
-    PyObject *tuple, *digits, *exp, *sig, *ten, *tmp, *ret = NULL;
+    PyObject *tuple, *digits, *exp, *sig, *ten, *tmp = NULL, *ret = NULL;
     int sign = 0;
     bool sharing;
 
